========================
Horizon TestCase Classes
========================

.. module:: horizon.test.helpers

Horizon provides a base test case class which provides several useful
pre-prepared attributes for testing Horizon components.

.. autoclass:: TestCase
    :members:

.. module :: openstack_dashboard.test.helpers

The OpenStack Dashboard also provides test case classes for greater
ease-of-use when testing APIs and OpenStack-specific auth scenarios.

.. autoclass:: TestCase
    :members:

.. autoclass:: APITestCase
    :members:

.. autoclass:: BaseAdminViewTests
    :members:
